The number of claims \(y_i\) on a life insurance policy for each of \(k=72\) Norwegian occupational categories and the total number of years the workers in each category were exposed to risk (\(E_i\)).
data("NorbergIns")A data frame of the occupational group number (group), the number of deaths (deaths), and the years of exposure (exposure) for \(i = 1,...,72\).
groupOccupational group number
deathsThe number of deaths in the occupational group resulting in a claim on a life insurance policy.
exposureThe total number of years of exposure to risk for those who passed.
Koenker, R. and Gu, J., 2017. "REBayes: An R Package for Empirical Bayes Mixture Methods," Journal of Statistical Software, Articles, 82(8), pp. 1-26.